# 2022-03-25 - Gauge Controller

Deployment of the `VotingEscrow`, which allows users to stake 80/20 BAL/WETH BPT to receive veBAL. Holding veBAL gives voting powers on the `GaugeController`, to direct BAL emissions to pool gauges.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`VotingEscrow` artifact](./artifact/VotingEscrow.json)
- [`GaugeController` artifact](./artifact/GaugeController.json)
- [`BalancerMinter` artifact](./artifact/BalancerMinter.json)
